@@ -8,15 +8,32 @@ import jsonschema
 
 from jsonrpcclient import rpc
 from jsonrpcclient import exceptions
-from jsonrpcclient import logger
+from jsonrpcclient import request_log, response_log
 
 
+DEFAULT_HTTP_HEADER = {
+    'Content-Type': 'application/json',
+    'Accept': 'application/json'
+}
+
 class Server:
     """This class acts as the remote server"""
 
-    def __init__(self, endpoint, auth=None):
-        self.auth = auth
+    def __init__(self, endpoint, headers=None, auth=None):
+        """Instantiate a remote server object.
+
+        >>> server = Server('http://example.com/api', \
+                headers={'Content-Type': 'application/json-rpc'}, \
+                auth=('user', 'pass'))
+        """
+
         self.endpoint = endpoint
+        self.auth = auth
+
+        if headers:
+            self.headers = headers
+        else:
+            self.headers = DEFAULT_HTTP_HEADER
 
     def __getattr__(self, name):
         """Catch undefined methods and handle them as RPC requests.
@@ -56,15 +73,13 @@ class Server:
         """
 
         # Log the request
-        logger.info('--> '+json.dumps(request_dict))
+        request_log.info(json.dumps(request_dict))
 
         try:
             # Send the message
             response = requests.post(
                 self.endpoint,
-                headers={
-                    'Content-Type': 'application/json; charset=utf-8'
-                },
+                self.headers,
                 json=request_dict,
                 auth=self.auth
             )
@@ -73,17 +88,14 @@ class Server:
         except requests.exceptions.RequestException: # The base exception
             raise exceptions.ConnectionError()
 
-        # Log the response
-        if len(response.text):
-            # Log the response
-            logger.info('<-- {} {}'.format(response.status_code, response.text)\
-                .replace("\n", '') \
-                .replace('  ', ' ') \
-                .replace('{ ', '{'))
-
-        else:
-            logger.info('<-- {} {}'.format(
-                response.status_code, response.reason))
+        # Log the response, cleaning it up a bit
+        response_log.info(
+            response.text \
+                .replace("\n", '').replace('  ', ' ').replace('{ ', '{'),
+            extra={
+                'http_code': response.status_code,
+                'http_reason': response.reason,
+            })
 
         return response
 
